==> hasktags-0.70.1-7-x86_64.pkg.tar.xz: usr/share/haskell/register/hasktags.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hasktags
version: 0.70.1
id: hasktags-0.70.1-LMzD9MN5nJU3UGGqUOeWHq
key: hasktags-0.70.1-LMzD9MN5nJU3UGGqUOeWHq
license: BSD-3-Clause
copyright: The University Court of the University of Glasgow
maintainer: Jack Henahan <jhenahan@me.com>,
            Marc Weber <marco-oweber@gmx.de>,
            Marco Túlio Pimenta Gontijo <marcotmarcot@gmail.com>
author: The GHC Team
homepage: http://github.com/MarcWeber/hasktags
synopsis: Produces ctags "tags" and etags "TAGS" files for Haskell programs
description:
    Produces ctags "tags" and etags "TAGS" files for Haskell programs.
category: Development
abi: 1378914cae739ab1f9a1c4d12c01662f
exposed: True
exposed-modules:
    Hasktags
hidden-modules: Tags DebugShow
import-dirs: /usr/lib/ghc-8.4.3/site-local/hasktags-0.70.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/hasktags-0.70.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/hasktags-0.70.1
hs-libraries: HShasktags-0.70.1-LMzD9MN5nJU3UGGqUOeWHq
depends:
    utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8 base-4.11.1.0
    bytestring-0.10.8.2 directory-1.3.1.5 filepath-1.4.2
    json-0.9.2-CSdog26Dq1kKFLQDw9tobB
    microlens-platform-0.3.10-LdG72Kl15AMJV5tclk6pdC
abi-depends: utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8=2191a818a7f61b012f58bd96949826c6
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             directory-1.3.1.5=e563da47c8e71ee27761a9b9d172f1ec
             filepath-1.4.2=f8b35940dbf3bb5331e1c5ab9738687d
             json-0.9.2-CSdog26Dq1kKFLQDw9tobB=565e21b24c351c4d8f21fb8ceec441ac
             microlens-platform-0.3.10-LdG72Kl15AMJV5tclk6pdC=e577d03475fb5790907e537c8f31f1a9
haddock-interfaces: /usr/share/doc/hasktags/html/hasktags.haddock
haddock-html: /usr/share/doc/hasktags/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> hasktags-0.70.1-8-x86_64.pkg.tar.xz: usr/share/haskell/register/hasktags.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hasktags
version: 0.70.1
id: hasktags-0.70.1-4QdtsD6AJNm2NDJff9tFIK
key: hasktags-0.70.1-4QdtsD6AJNm2NDJff9tFIK
license: BSD-3-Clause
copyright: The University Court of the University of Glasgow
maintainer: Jack Henahan <jhenahan@me.com>,
            Marc Weber <marco-oweber@gmx.de>,
            Marco Túlio Pimenta Gontijo <marcotmarcot@gmail.com>
author: The GHC Team
homepage: http://github.com/MarcWeber/hasktags
synopsis: Produces ctags "tags" and etags "TAGS" files for Haskell programs
description:
    Produces ctags "tags" and etags "TAGS" files for Haskell programs.
category: Development
abi: 44508d2f4fa7ed634327fc1f99c2a527
exposed: True
exposed-modules:
    Hasktags
hidden-modules: Tags DebugShow
import-dirs: /usr/lib/ghc-8.4.3/site-local/hasktags-0.70.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/hasktags-0.70.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/hasktags-0.70.1
hs-libraries: HShasktags-0.70.1-4QdtsD6AJNm2NDJff9tFIK
depends:
    utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8 base-4.11.1.0
    bytestring-0.10.8.2 directory-1.3.1.5 filepath-1.4.2
    json-0.9.2-CSdog26Dq1kKFLQDw9tobB
    microlens-platform-0.3.10-IGO8ibpklfKGxXHbR2em54
abi-depends: utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8=2191a818a7f61b012f58bd96949826c6
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             directory-1.3.1.5=e563da47c8e71ee27761a9b9d172f1ec
             filepath-1.4.2=f8b35940dbf3bb5331e1c5ab9738687d
             json-0.9.2-CSdog26Dq1kKFLQDw9tobB=565e21b24c351c4d8f21fb8ceec441ac
             microlens-platform-0.3.10-IGO8ibpklfKGxXHbR2em54=aa742a6a9c77fdf5f2912f127f9881ef
haddock-interfaces: /usr/share/doc/hasktags/html/hasktags.haddock
haddock-html: /usr/share/doc/hasktags/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
